let highlightOverlay = null; // Overlay for highlighting elements

// Add hover listener to highlight elements
document.addEventListener('mouseover', (event) => {
    const target = event.target;

    // Skip if hovering over the overlay itself
    if (target === highlightOverlay) return;

    // Create or update the highlight overlay
    if (!highlightOverlay) {
        highlightOverlay = document.createElement('div');
        document.body.appendChild(highlightOverlay);
        styleHighlightOverlay(highlightOverlay);
    }

    // Get the target element's bounding rectangle
    const rect = target.getBoundingClientRect();

    // Position and size the overlay to match the hovered element
    highlightOverlay.style.top = `${rect.top + window.scrollY}px`;
    highlightOverlay.style.left = `${rect.left + window.scrollX}px`;
    highlightOverlay.style.width = `${rect.width}px`;
    highlightOverlay.style.height = `${rect.height}px`;
    highlightOverlay.style.display = 'block';
});

// Remove the highlight overlay on mouseout
document.addEventListener('mouseout', () => {
    if (highlightOverlay) {
        highlightOverlay.style.display = 'none';
    }
});

// Handle link clicks
document.addEventListener('click', (event) => {
    const target = event.target;

    // Check if the clicked element is a link
    if (target.tagName === 'A') {
        const clickedUrl = target.href;

        console.log('Link Clicked:', clickedUrl);

        // Send the clicked URL to the parent
        window.parent.postMessage(
            {
                type: 'linkClick',
                data: { href: clickedUrl },
            },
            '*'
        );

        // Prevent default navigation behavior
        event.preventDefault();
    }
});

// Handle text selection and element HTML on double-click
document.addEventListener('dblclick', (event) => {
    const target = event.target;

    // Get the full HTML and plain text of the clicked element
    const fullHtml = target.innerHTML; // Full HTML of the clicked element
    const selectedText = target.textContent.trim(); // Full plain text of the clicked element
    // Send the data to the parent or handle it further
    window.parent.postMessage(
        {
            type: 'textSelect',
            data: {
                selectedText, // Include the selected text
                fullHtml, // Include the full HTML of the element
            },
        },
        '*'
    );
});


// Utility: Style the highlight overlay
function styleHighlightOverlay(overlay) {
    overlay.style.position = 'absolute';
    overlay.style.pointerEvents = 'none'; // Ignore pointer events
    overlay.style.backgroundColor = 'rgba(0, 123, 255, 0.2)'; // Highlight color
    overlay.style.border = '2px solid rgba(0, 123, 255, 0.8)'; // Border color
    overlay.style.zIndex = '9999'; // Ensure it's above all other elements
    overlay.style.display = 'none'; // Initially hidden
}
